@@ -2,7 +2,7 @@ from ._version import __version__  # noqa: F401
 # :obj:`str`: version
 
 from .config import Config
-from .core import exec_sed_task, exec_sedml_docs_in_combine_archive  # noqa: F401
+from .core import exec_sed_task, preprocess_sed_task, exec_sed_doc, exec_sedml_docs_in_combine_archive  # noqa: F401
 
 import subprocess
 
@@ -11,6 +11,8 @@ __all = [
     '__version__',
     'get_simulator_version',
     'exec_sed_task',
+    'preprocess_sed_task',
+    'exec_sed_doc',
     'exec_sedml_docs_in_combine_archive',
 ]
 
